bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.plates_from_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.plates_from_parent